@@ -72,6 +72,10 @@ func SetTag(key string, value string) {
 func AddLog(...string) {
 }
 
+func AddEvent(et EventType, event string) {
+
+}
+
 func GetCorrelation(key string) string {
 	return ""
 }
@@ -82,3 +86,6 @@ func SetCorrelation(key string, value string) {
 
 func SetComponent(componentID int32) {
 }
+
+func Error(...string) {
+}
