@@ -20,7 +20,6 @@ package tools
 import (
 	"fmt"
 	"go/token"
-	"strings"
 
 	"github.com/dave/dst"
 	"github.com/dave/dst/decorator"
@@ -31,10 +30,9 @@ const OtherPackageRefPrefix = "swref_"
 const parameterAppender = ", "
 
 type ParameterInfo struct {
-	Name                 string
-	Type                 dst.Expr
-	DefaultValueAsString string
-	TypeName             string
+	Name     string
+	Type     dst.Expr
+	TypeName string
 }
 
 type PackagedParameterInfo struct {
@@ -91,7 +89,6 @@ func EnhanceParameterNames(fields *dst.FieldList, fieldType FieldListType) []*Pa
 
 			for _, n := range f.Names {
 				result = append(result, newParameterInfo(n.Name, f.Type))
-				break
 			}
 		}
 	}
@@ -141,24 +138,6 @@ func newParameterInfo(name string, tp dst.Expr) *ParameterInfo {
 		Type:     tp,
 		TypeName: GenerateTypeNameByExp(tp),
 	}
-	var defaultNil = "nil"
-	switch n := tp.(type) {
-	case *dst.Ident:
-		if n.Name == "string" {
-			defaultNil = `""`
-		} else if n.Name == "bool" {
-			defaultNil = "false"
-		} else if strings.HasPrefix(n.Name, "int") || strings.HasPrefix(n.Name, "uint") ||
-			strings.HasPrefix(n.Name, "float") || n.Name == "byte" || n.Name == "rune" {
-			defaultNil = "0"
-		}
-	case *dst.UnaryExpr:
-		if n.Op == token.INT || n.Op == token.FLOAT {
-			defaultNil = "0"
-		}
-	}
-	result.DefaultValueAsString = defaultNil
-
 	return result
 }
 
@@ -209,6 +188,16 @@ func GenerateTypeNameByExp(exp dst.Expr) string {
 			}
 			data += ")"
 		}
+	case *dst.ChanType:
+		if n.Dir == dst.SEND {
+			data += token.CHAN.String() + token.ARROW.String()
+		} else if n.Dir == dst.RECV {
+			data += token.ARROW.String() + token.CHAN.String()
+		} else {
+			data += token.CHAN.String()
+		}
+		data += " " + GenerateTypeNameByExp(n.Value)
+		return data
 	default:
 		return ""
 	}
@@ -243,6 +232,9 @@ func addPackagePrefixForArgsAndClone(pkg string, tp dst.Expr) dst.Expr {
 			exp.X = dst.NewIdent(OtherPackageRefPrefix + pkg)
 		}
 		return exp
+	case *dst.ChanType:
+		expr := dst.Clone(tp).(*dst.ChanType)
+		return expr
 	default:
 		return dst.Clone(tp).(dst.Expr)
 	}
